Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2523)

Unified Diff: chrome/browser/policy/device_policy_identity_strategy.h

Issue 6821045: Connect enrollment screen to cloud policy subsystem. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix unit tests... Created 9 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/policy/device_policy_identity_strategy.h
diff --git a/chrome/browser/policy/device_policy_identity_strategy.h b/chrome/browser/policy/device_policy_identity_strategy.h
index 2c172c354691ec2614e97e04ffa9134fbbc3c3fb..64695ecd0c50b3b2bdcdafeaf1cad8b112623ed3 100644
--- a/chrome/browser/policy/device_policy_identity_strategy.h
+++ b/chrome/browser/policy/device_policy_identity_strategy.h
@@ -25,8 +25,7 @@ class DevicePolicyIdentityStrategy : public CloudPolicyIdentityStrategy {
// enrollment. This automatically triggers fetching a DMToken that can
// be used for future authentication with DMServer.
void SetAuthCredentials(const std::string& username,
- const std::string& auth_token,
- const std::string& machine_id);
+ const std::string& auth_token);
// Sets the device's credentials when they have been read from disk after
// a reboot.
@@ -38,6 +37,7 @@ class DevicePolicyIdentityStrategy : public CloudPolicyIdentityStrategy {
virtual std::string GetDeviceToken() OVERRIDE;
virtual std::string GetDeviceID() OVERRIDE;
virtual std::string GetMachineID() OVERRIDE;
+ virtual std::string GetMachineModel() OVERRIDE;
virtual em::DeviceRegisterRequest_Type GetPolicyRegisterType() OVERRIDE;
virtual std::string GetPolicyType() OVERRIDE;
virtual bool GetCredentials(std::string* username,
@@ -49,8 +49,9 @@ class DevicePolicyIdentityStrategy : public CloudPolicyIdentityStrategy {
std::string username_;
std::string auth_token_;
// The machine identifier.
std::string machine_id_;
+ std::string machine_model_;
// The device identifier to be sent with requests. (This is actually more like
// a session identifier since it is re-generated for each registration
« no previous file with comments | « chrome/browser/policy/cloud_policy_identity_strategy.h ('k') | chrome/browser/policy/device_policy_identity_strategy.cc » ('j') | no next file with comments »
@@ -49,8 +49,9 @@ class DevicePolicyIdentityStrategy : public CloudPolicyIdentityStrategy {
std::string username_;
std::string auth_token_;
- // The machine identifier.
+ // The machine identifier and model.
std::string machine_id_;

Powered by Google App Engine
This is Rietveld 408576698